@@ -95,8 +95,6 @@ link_public_api(int)
      parse_options_get_max_parse_time(Parse_Options opts);
 link_public_api(void)
      parse_options_set_cost_model_type(Parse_Options opts, int cm);
-link_public_api(int)
-     parse_options_get_cost_model_type(Parse_Options opts);
 link_public_api(int)
      parse_options_timer_expired(Parse_Options opts);
 link_public_api(int)
@@ -201,6 +199,10 @@ link_public_api(int)
 link_public_api(int)
      sentence_disjunct_cost(Sentence sent, int i);
 
+link_public_api(char *)
+     sentence_get_nth_word(Sentence sent, int i);
+link_public_api(int)
+     sentence_nth_word_has_disjunction(Sentence sent, int i);
 
 /*****************************************************************************
 *
@@ -256,8 +258,6 @@ link_public_api(char *)
      linkage_print_postscript(Linkage linkage, int mode);
 link_public_api(char *)
      linkage_print_diagram(Linkage linkage);
-link_public_api(char *)
-     linkage_print_constituents(Linkage linkage);
 link_public_api(int)
      linkage_compute_union(Linkage linkage);
 link_public_api(int)
