@@ -12,7 +12,7 @@
 /********************************************************************************/
 
 #include <stdarg.h>
-#include <link-grammar/link-includes.h>
+#include <link-grammar/api.h>
 
 /* This is a "safe" append function, used here to build up a link diagram
    incrementally.  Because the diagram is built up a few characters at
