@@ -520,7 +520,8 @@ FILE *dictopen(char *dictname, char *filename, char *how) {
     FILE *fp;
 
     if (filename[0] == '/') {
-	return fopen(filename, how);  /* If the file does not exist NULL is returned */
+	fp = fopen(filename, how);  /* If the file does not exist NULL is returned */
+	if(fp) return fp;
     }
 
     {
@@ -530,7 +531,9 @@ FILE *dictopen(char *dictname, char *filename, char *how) {
 	free(data_dir);
       }
       else {
-	strcpy(fulldictpath, DEFAULTPATH);
+	/* always make sure that it ends with a path separator char 
+	   for the below while() loop. */
+	sprintf(fulldictpath, "%s%c", DEFAULTPATH, PATH_SEPARATOR);
       }
     }
 
